==> tasker-akka-9.7.1-sources.jar: com/xebialabs/deployit/engine/tasker/ReceiveWithMdc.scala <==
package com.xebialabs.deployit.engine.tasker

import akka.actor.Actor
import akka.actor.Actor._
import com.xebialabs.deployit.engine.tasker.ArchiveActor.messages.SendToArchive
import com.xebialabs.deployit.engine.tasker.MdcUtils._
import com.xebialabs.deployit.engine.tasker.StepExecutingActor.messages.ExecuteStep
import com.xebialabs.deployit.engine.tasker.TaskManagingActor.messages.{Recovered, Register}
import com.xebialabs.deployit.engine.tasker.messages.TaskDone

trait BecomeWithMdc {
  self: Actor =>
  val task: Task

  def becomeWithMdc(receive: Receive, discardOld: Boolean = true): Unit = context become(ReceiveWithMdc(task)(receive), discardOld)

}

object ReceiveWithMdc {

  def apply(task: Task)(r: Receive): Receive = new ReceiveWithMdc(Some(task), Some(task.getId), r)

  def apply(taskId: TaskId)(r: Receive): Receive = new ReceiveWithMdc(None, Some(taskId), r)

  def apply()(r: Receive): Receive = new ReceiveWithMdc(None, None, r)

}

class ReceiveWithMdc(task: Option[Task], taskId: Option[TaskId], realReceive: Receive) extends Receive {

  def isDefinedAt(o: Any) = realReceive.isDefinedAt(o)

  def apply(message: Any): Unit = withMdc(mdcWithTaskAndMessage(message)) {
    realReceive(message)
  }

  private def mdcWithTaskAndMessage(message: Any): Map[String, TaskId] = {
    val extraMdc = task.map(mdcWithTask).getOrElse(Map()) ++
      taskId.map(taskId => {
        Map(TaskIdAttributeName -> taskId)
      }).getOrElse(Map()) ++ {
      message match {
        case ExecuteStep(s, ctx) => Map(StepDescriptionAttributeName -> s.getDescription)
        case Recovered(t) => mdcWithTask(t)
        case SendToArchive(t, _) => mdcWithTask(t)
        case TaskDone(t) => mdcWithTask(t)
        case _ => Map()
      }
    }
    extraMdc
  }
}

==> tasker-akka-10.2.0-511.829-sources.jar: com/xebialabs/deployit/engine/tasker/ReceiveWithMdc.scala <==
package com.xebialabs.deployit.engine.tasker

import akka.actor.Actor
import akka.actor.Actor._
import com.xebialabs.deployit.engine.tasker.ArchiveActor.messages.SendToArchive
import com.xebialabs.deployit.engine.tasker.MdcUtils._
import com.xebialabs.deployit.engine.tasker.StepExecutingActor.messages.ExecuteStep
import com.xebialabs.deployit.engine.tasker.TaskManagingActor.messages.{Recovered, Register}
import com.xebialabs.deployit.engine.tasker.messages.TaskDone

trait BecomeWithMdc {
  self: Actor =>
  val task: Task

  def becomeWithMdc(receive: Receive, discardOld: Boolean = true): Unit = context.become(ReceiveWithMdc(task)(receive), discardOld)

}

object ReceiveWithMdc {

  def apply(task: Task)(r: Receive): Receive = new ReceiveWithMdc(Some(task), Some(task.getId), r)

  def apply(taskId: TaskId)(r: Receive): Receive = new ReceiveWithMdc(None, Some(taskId), r)

  def apply()(r: Receive): Receive = new ReceiveWithMdc(None, None, r)

}

class ReceiveWithMdc(task: Option[Task], taskId: Option[TaskId], realReceive: Receive) extends Receive {

  def isDefinedAt(o: Any) = realReceive.isDefinedAt(o)

  def apply(message: Any): Unit = withMdc(mdcWithTaskAndMessage(message)) {
    realReceive(message)
  }

  private def mdcWithTaskAndMessage(message: Any): Map[String, TaskId] = {
    val extraMdc = task.map(mdcWithTask).getOrElse(Map()) ++
      taskId.map(taskId => {
        Map(TaskIdAttributeName -> taskId)
      }).getOrElse(Map()) ++ {
      message match {
        case ExecuteStep(s, ctx) => Map(StepDescriptionAttributeName -> s.getDescription)
        case Recovered(t) => mdcWithTask(t)
        case SendToArchive(t, _) => mdcWithTask(t)
        case TaskDone(t) => mdcWithTask(t)
        case _ => Map()
      }
    }
    extraMdc
  }
}
